==> percona-server-mongodb_4.4.1.orig.tar.gz: percona-server-mongodb-4.4.1-2/aws-sdk-cpp/aws-cpp-sdk-medialive/source/model/ReservationResourceType.cpp <==
﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/medialive/model/ReservationResourceType.h>
#include <aws/core/utils/HashingUtils.h>
#include <aws/core/Globals.h>
#include <aws/core/utils/EnumParseOverflowContainer.h>

using namespace Aws::Utils;


namespace Aws
{
  namespace MediaLive
  {
    namespace Model
    {
      namespace ReservationResourceTypeMapper
      {

        static const int INPUT_HASH = HashingUtils::HashString("INPUT");
        static const int OUTPUT_HASH = HashingUtils::HashString("OUTPUT");
        static const int CHANNEL_HASH = HashingUtils::HashString("CHANNEL");


        ReservationResourceType GetReservationResourceTypeForName(const Aws::String& name)
        {
          int hashCode = HashingUtils::HashString(name.c_str());
          if (hashCode == INPUT_HASH)
          {
            return ReservationResourceType::INPUT;
          }
          else if (hashCode == OUTPUT_HASH)
          {
            return ReservationResourceType::OUTPUT;
          }
          else if (hashCode == CHANNEL_HASH)
          {
            return ReservationResourceType::CHANNEL;
          }
          EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
          if(overflowContainer)
          {
            overflowContainer->StoreOverflow(hashCode, name);
            return static_cast<ReservationResourceType>(hashCode);
          }

          return ReservationResourceType::NOT_SET;
        }

        Aws::String GetNameForReservationResourceType(ReservationResourceType enumValue)
        {
          switch(enumValue)
          {
          case ReservationResourceType::INPUT:
            return "INPUT";
          case ReservationResourceType::OUTPUT:
            return "OUTPUT";
          case ReservationResourceType::CHANNEL:
            return "CHANNEL";
          default:
            EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
            if(overflowContainer)
            {
              return overflowContainer->RetrieveOverflow(static_cast<int>(enumValue));
            }

            return {};
          }
        }

      } // namespace ReservationResourceTypeMapper
    } // namespace Model
  } // namespace MediaLive
} // namespace Aws

==> percona-server-mongodb-36_3.6.23.orig.tar.gz: percona-server-mongodb-3.6.23-13.0/aws-sdk-cpp/aws-cpp-sdk-medialive/source/model/ReservationResourceType.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/medialive/model/ReservationResourceType.h>
#include <aws/core/utils/HashingUtils.h>
#include <aws/core/Globals.h>
#include <aws/core/utils/EnumParseOverflowContainer.h>

using namespace Aws::Utils;


namespace Aws
{
  namespace MediaLive
  {
    namespace Model
    {
      namespace ReservationResourceTypeMapper
      {

        static const int INPUT_HASH = HashingUtils::HashString("INPUT");
        static const int OUTPUT_HASH = HashingUtils::HashString("OUTPUT");
        static const int MULTIPLEX_HASH = HashingUtils::HashString("MULTIPLEX");
        static const int CHANNEL_HASH = HashingUtils::HashString("CHANNEL");


        ReservationResourceType GetReservationResourceTypeForName(const Aws::String& name)
        {
          int hashCode = HashingUtils::HashString(name.c_str());
          if (hashCode == INPUT_HASH)
          {
            return ReservationResourceType::INPUT;
          }
          else if (hashCode == OUTPUT_HASH)
          {
            return ReservationResourceType::OUTPUT;
          }
          else if (hashCode == MULTIPLEX_HASH)
          {
            return ReservationResourceType::MULTIPLEX;
          }
          else if (hashCode == CHANNEL_HASH)
          {
            return ReservationResourceType::CHANNEL;
          }
          EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
          if(overflowContainer)
          {
            overflowContainer->StoreOverflow(hashCode, name);
            return static_cast<ReservationResourceType>(hashCode);
          }

          return ReservationResourceType::NOT_SET;
        }

        Aws::String GetNameForReservationResourceType(ReservationResourceType enumValue)
        {
          switch(enumValue)
          {
          case ReservationResourceType::INPUT:
            return "INPUT";
          case ReservationResourceType::OUTPUT:
            return "OUTPUT";
          case ReservationResourceType::MULTIPLEX:
            return "MULTIPLEX";
          case ReservationResourceType::CHANNEL:
            return "CHANNEL";
          default:
            EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
            if(overflowContainer)
            {
              return overflowContainer->RetrieveOverflow(static_cast<int>(enumValue));
            }

            return {};
          }
        }

      } // namespace ReservationResourceTypeMapper
    } // namespace Model
  } // namespace MediaLive
} // namespace Aws
